;; Generated package description from dape.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dape" "0.27.1.0.20260719.8" "Debug Adapter Protocol for Emacs" '((emacs "29.1") (jsonrpc "1.0.25")) :commit "b04e927abac6fcbef480c8a39881d69baa1bec98" :maintainer '("Daniel Pettersson" . "daniel@dpettersson.net") :url "https://github.com/svaante/dape")
